import { z, ZodError } from 'zod';
import { bq as UnwrapPromise, F as FeltController, z as zInfer, c as ElementChangeCallbackParams, f as ElementGroupChangeCallbackParams, E as Element, D as MapInteractionEvent, $ as LayerChangeCallbackParams, a2 as LayerGroupChangeCallbackParams, a5 as LegendItemChangeCallbackParams, at as LayerFilters, as as LayerBoundaries, ap as FilterTernary, aI as EntityNode, bh as ToolType, bf as ToolSettingsChangeEvent, bo as ViewportState, br as UnionToIntersection, bs as PromiseOrNot } from './controller-C5gGWnaM.js';

type FeltControllerFunctions = Omit<FeltController, "iframe">;
type Method<TRequest extends {
    type: keyof FeltControllerFunctions;
    params?: any;
}> = {
    request: TRequest;
    response: UnwrapPromise<ReturnType<FeltControllerFunctions[TRequest["type"]]>>;
};
type Listener<TOptions, TParams> = {
    options: TOptions;
    eventParams: TParams;
};
type ListenerNoOptions<TParams> = {
    eventParams: TParams;
};

declare const GetElementMessage: z.ZodObject<{
    type: z.ZodLiteral<"getElement">;
    params: z.ZodString;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: string;
    type: "getElement";
}, {
    params: string;
    type: "getElement";
}>;
declare const GetElementGeometryMessage: z.ZodObject<{
    type: z.ZodLiteral<"getElementGeometry">;
    params: z.ZodString;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: string;
    type: "getElementGeometry";
}, {
    params: string;
    type: "getElementGeometry";
}>;
declare const GetElementsMessage: z.ZodObject<{
    type: z.ZodLiteral<"getElements">;
    params: z.ZodOptional<z.ZodObject<{
        ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        ids?: string[] | undefined;
    }, {
        ids?: string[] | undefined;
    }>>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "getElements";
    params?: {
        ids?: string[] | undefined;
    } | undefined;
}, {
    type: "getElements";
    params?: {
        ids?: string[] | undefined;
    } | undefined;
}>;
declare const GetGroupMessage$1: z.ZodObject<{
    type: z.ZodLiteral<"getElementGroup">;
    params: z.ZodString;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: string;
    type: "getElementGroup";
}, {
    params: string;
    type: "getElementGroup";
}>;
declare const GetGroupsMessage$1: z.ZodObject<{
    type: z.ZodLiteral<"getElementGroups">;
    params: z.ZodOptional<z.ZodObject<{
        ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        ids?: string[] | undefined;
    }, {
        ids?: string[] | undefined;
    }>>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "getElementGroups";
    params?: {
        ids?: string[] | undefined;
    } | undefined;
}, {
    type: "getElementGroups";
    params?: {
        ids?: string[] | undefined;
    } | undefined;
}>;
declare const SetElementGroupVisibilityMessage: z.ZodObject<{
    type: z.ZodLiteral<"setElementGroupVisibility">;
    params: z.ZodObject<{
        show: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        hide: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    }, {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    };
    type: "setElementGroupVisibility";
}, {
    params: {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    };
    type: "setElementGroupVisibility";
}>;
declare const OnElementChangeMessage: z.ZodObject<{
    eventName: z.ZodLiteral<"onElementChange">;
    id: z.ZodString;
    options: z.ZodObject<{
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
    }, {
        id: string;
    }>;
}, "strict", z.ZodTypeAny, {
    options: {
        id: string;
    };
    id: string;
    eventName: "onElementChange";
}, {
    options: {
        id: string;
    };
    id: string;
    eventName: "onElementChange";
}>;
declare const OnElementDeleteMessage: z.ZodObject<{
    eventName: z.ZodLiteral<"onElementDelete">;
    id: z.ZodString;
    options: z.ZodObject<{
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
    }, {
        id: string;
    }>;
}, "strict", z.ZodTypeAny, {
    options: {
        id: string;
    };
    id: string;
    eventName: "onElementDelete";
}, {
    options: {
        id: string;
    };
    id: string;
    eventName: "onElementDelete";
}>;
declare const OnElementGroupChangeMessage: z.ZodObject<{
    eventName: z.ZodLiteral<"onElementGroupChange">;
    id: z.ZodString;
    options: z.ZodObject<{
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
    }, {
        id: string;
    }>;
}, "strict", z.ZodTypeAny, {
    options: {
        id: string;
    };
    id: string;
    eventName: "onElementGroupChange";
}, {
    options: {
        id: string;
    };
    id: string;
    eventName: "onElementGroupChange";
}>;
declare const CreateElementMessage: z.ZodObject<{
    type: z.ZodLiteral<"createElement">;
    params: z.ZodDiscriminatedUnion<"type", [z.ZodObject<Omit<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        type: z.ZodOptional<z.ZodLiteral<"Place">>;
        coordinates: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
        symbol: z.ZodOptional<z.ZodString>;
        frame: z.ZodOptional<z.ZodNullable<z.ZodEnum<["frame-circle", "frame-square"]>>>;
        hideLabel: z.ZodOptional<z.ZodBoolean>;
    }, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        imageUrl: z.ZodNullable<z.ZodString>;
    }>, {
        type: z.ZodLiteral<"Place">;
        coordinates: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
        symbol: z.ZodString;
        frame: z.ZodNullable<z.ZodEnum<["frame-circle", "frame-square"]>>;
        hideLabel: z.ZodBoolean;
    }>, "type" | "coordinates">>, "id">, "strip", z.ZodTypeAny, {
        type: "Place";
        coordinates: [number, number];
        symbol?: string | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        hideLabel?: boolean | undefined;
    }, {
        type: "Place";
        coordinates: [number, number];
        symbol?: string | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        hideLabel?: boolean | undefined;
    }>, z.ZodObject<Omit<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        strokeOpacity: z.ZodOptional<z.ZodNumber>;
        strokeWidth: z.ZodOptional<z.ZodNumber>;
        strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
        type: z.ZodOptional<z.ZodLiteral<"Path">>;
        coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
        distanceMarker: z.ZodOptional<z.ZodBoolean>;
        routingMode: z.ZodOptional<z.ZodNullable<z.ZodEnum<["driving", "cycling", "walking", "flying"]>>>;
        endCaps: z.ZodOptional<z.ZodBoolean>;
    }, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        imageUrl: z.ZodNullable<z.ZodString>;
    }>, {
        strokeOpacity: z.ZodNumber;
        strokeWidth: z.ZodNumber;
        strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
    }>, {
        type: z.ZodLiteral<"Path">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
        distanceMarker: z.ZodBoolean;
        routingMode: z.ZodNullable<z.ZodEnum<["driving", "cycling", "walking", "flying"]>>;
        endCaps: z.ZodBoolean;
    }>, "type" | "coordinates">>, "id">, "strip", z.ZodTypeAny, {
        type: "Path";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    }, {
        type: "Path";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    }>, z.ZodObject<Omit<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        strokeOpacity: z.ZodOptional<z.ZodNumber>;
        strokeWidth: z.ZodOptional<z.ZodNumber>;
        strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
        type: z.ZodOptional<z.ZodLiteral<"Polygon">>;
        coordinates: z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">>;
        fillOpacity: z.ZodOptional<z.ZodNumber>;
        areaMarker: z.ZodOptional<z.ZodBoolean>;
    }, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        imageUrl: z.ZodNullable<z.ZodString>;
    }>, {
        strokeOpacity: z.ZodNumber;
        strokeWidth: z.ZodNumber;
        strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
    }>, {
        type: z.ZodLiteral<"Polygon">;
        coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
        fillOpacity: z.ZodNumber;
        areaMarker: z.ZodBoolean;
    }>, "type" | "coordinates">>, "id">, "strip", z.ZodTypeAny, {
        type: "Polygon";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    }, {
        type: "Polygon";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    }>, z.ZodObject<Omit<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        strokeOpacity: z.ZodOptional<z.ZodNumber>;
        strokeWidth: z.ZodOptional<z.ZodNumber>;
        strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
        type: z.ZodOptional<z.ZodLiteral<"Circle">>;
        center: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
        radius: z.ZodOptional<z.ZodNumber>;
        radiusMarker: z.ZodOptional<z.ZodBoolean>;
        radiusDisplayAngle: z.ZodOptional<z.ZodNumber>;
        radiusDisplayUnit: z.ZodOptional<z.ZodNullable<z.ZodEnum<["meter", "kilometer", "foot", "mile"]>>>;
        fillOpacity: z.ZodOptional<z.ZodNumber>;
    }, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        imageUrl: z.ZodNullable<z.ZodString>;
    }>, {
        strokeOpacity: z.ZodNumber;
        strokeWidth: z.ZodNumber;
        strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
    }>, {
        type: z.ZodLiteral<"Circle">;
        center: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
        radius: z.ZodNumber;
        radiusMarker: z.ZodBoolean;
        radiusDisplayAngle: z.ZodNumber;
        radiusDisplayUnit: z.ZodNullable<z.ZodEnum<["meter", "kilometer", "foot", "mile"]>>;
        fillOpacity: z.ZodNumber;
    }>, "type" | "center" | "radius">>, "id">, "strip", z.ZodTypeAny, {
        type: "Circle";
        center: [number, number];
        radius: number;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        radiusMarker?: boolean | undefined;
        radiusDisplayAngle?: number | undefined;
        radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
    }, {
        type: "Circle";
        center: [number, number];
        radius: number;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        radiusMarker?: boolean | undefined;
        radiusDisplayAngle?: number | undefined;
        radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
    }>, z.ZodObject<Omit<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        type: z.ZodOptional<z.ZodLiteral<"Marker">>;
        coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
        opacity: z.ZodOptional<z.ZodNumber>;
        size: z.ZodOptional<z.ZodNumber>;
        zoom: z.ZodOptional<z.ZodNumber>;
    }, Pick<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        type: z.ZodLiteral<"Marker">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
        opacity: z.ZodNumber;
        size: z.ZodNumber;
        zoom: z.ZodNumber;
    }>, "type" | "coordinates">>, "id">, "strip", z.ZodTypeAny, {
        type: "Marker";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        zoom?: number | undefined;
    }, {
        type: "Marker";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        zoom?: number | undefined;
    }>, z.ZodObject<Omit<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        type: z.ZodOptional<z.ZodLiteral<"Highlighter">>;
        coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">>;
        renderHoles: z.ZodOptional<z.ZodBoolean>;
        opacity: z.ZodOptional<z.ZodNumber>;
    }, Pick<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        type: z.ZodLiteral<"Highlighter">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
        renderHoles: z.ZodBoolean;
        opacity: z.ZodNumber;
    }>, "type" | "coordinates">>, "id">, "strip", z.ZodTypeAny, {
        type: "Highlighter";
        coordinates: [number, number][][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        renderHoles?: boolean | undefined;
    }, {
        type: "Highlighter";
        coordinates: [number, number][][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        renderHoles?: boolean | undefined;
    }>, z.ZodObject<Omit<z.objectUtil.extendShape<{
        type: z.ZodOptional<z.ZodLiteral<"Image">>;
        coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        imageUrl: z.ZodOptional<z.ZodString>;
        opacity: z.ZodOptional<z.ZodNumber>;
    }, Pick<Omit<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        type: z.ZodLiteral<"Image">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
        imageUrl: z.ZodString;
        opacity: z.ZodNumber;
    }>, "color">, "type" | "coordinates" | "imageUrl">>, "id">, "strip", z.ZodTypeAny, {
        type: "Image";
        coordinates: [number, number][][];
        imageUrl: string;
        groupId?: string | null | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
    }, {
        type: "Image";
        coordinates: [number, number][][];
        imageUrl: string;
        groupId?: string | null | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<Omit<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        position: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
        rotation: z.ZodOptional<z.ZodNumber>;
        scale: z.ZodOptional<z.ZodNumber>;
        zoom: z.ZodOptional<z.ZodNumber>;
        text: z.ZodOptional<z.ZodString>;
        align: z.ZodOptional<z.ZodEnum<["left", "center", "right"]>>;
        style: z.ZodOptional<z.ZodEnum<["italic", "light", "regular", "caps"]>>;
        name: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodLiteral<"Text">>;
    }, "type" | "id" | "name">, {
        type: z.ZodLiteral<"Text">;
        text: z.ZodString;
    }>, "strip", z.ZodTypeAny, {
        type: "Text";
        text: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    }, {
        type: "Text";
        text: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<Omit<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        position: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
        rotation: z.ZodOptional<z.ZodNumber>;
        scale: z.ZodOptional<z.ZodNumber>;
        zoom: z.ZodOptional<z.ZodNumber>;
        text: z.ZodOptional<z.ZodString>;
        align: z.ZodOptional<z.ZodEnum<["left", "center", "right"]>>;
        style: z.ZodOptional<z.ZodEnum<["italic", "light", "regular", "caps"]>>;
        name: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodLiteral<"Note">>;
        widthScale: z.ZodOptional<z.ZodNumber>;
    }, "type" | "id" | "name">, {
        type: z.ZodLiteral<"Note">;
        text: z.ZodString;
    }>, "strip", z.ZodTypeAny, {
        type: "Note";
        text: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
        widthScale?: number | undefined;
    }, {
        type: "Note";
        text: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
        widthScale?: number | undefined;
    }>]>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        type: "Place";
        coordinates: [number, number];
        symbol?: string | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        hideLabel?: boolean | undefined;
    } | {
        type: "Path";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    } | {
        type: "Polygon";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    } | {
        type: "Circle";
        center: [number, number];
        radius: number;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        radiusMarker?: boolean | undefined;
        radiusDisplayAngle?: number | undefined;
        radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
    } | {
        type: "Marker";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        zoom?: number | undefined;
    } | {
        type: "Highlighter";
        coordinates: [number, number][][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        renderHoles?: boolean | undefined;
    } | {
        type: "Text";
        text: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    } | {
        type: "Note";
        text: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
        widthScale?: number | undefined;
    } | {
        type: "Image";
        coordinates: [number, number][][];
        imageUrl: string;
        groupId?: string | null | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
    };
    type: "createElement";
}, {
    params: {
        type: "Place";
        coordinates: [number, number];
        symbol?: string | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        hideLabel?: boolean | undefined;
    } | {
        type: "Path";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    } | {
        type: "Polygon";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    } | {
        type: "Circle";
        center: [number, number];
        radius: number;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        radiusMarker?: boolean | undefined;
        radiusDisplayAngle?: number | undefined;
        radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
    } | {
        type: "Marker";
        coordinates: [number, number][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        zoom?: number | undefined;
    } | {
        type: "Highlighter";
        coordinates: [number, number][][][];
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        renderHoles?: boolean | undefined;
    } | {
        type: "Text";
        text: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    } | {
        type: "Note";
        text: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
        widthScale?: number | undefined;
    } | {
        type: "Image";
        coordinates: [number, number][][];
        imageUrl: string;
        groupId?: string | null | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
    };
    type: "createElement";
}>;
declare const UpdateElementMessage: z.ZodObject<{
    type: z.ZodLiteral<"updateElement">;
    params: z.ZodDiscriminatedUnion<"type", [z.ZodObject<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        type: z.ZodOptional<z.ZodLiteral<"Place">>;
        coordinates: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
        symbol: z.ZodOptional<z.ZodString>;
        frame: z.ZodOptional<z.ZodNullable<z.ZodEnum<["frame-circle", "frame-square"]>>>;
        hideLabel: z.ZodOptional<z.ZodBoolean>;
    }, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        imageUrl: z.ZodNullable<z.ZodString>;
    }>, {
        type: z.ZodLiteral<"Place">;
        coordinates: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
        symbol: z.ZodString;
        frame: z.ZodNullable<z.ZodEnum<["frame-circle", "frame-square"]>>;
        hideLabel: z.ZodBoolean;
    }>, "type" | "id">>, "strip", z.ZodTypeAny, {
        type: "Place";
        id: string;
        symbol?: string | undefined;
        coordinates?: [number, number] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        hideLabel?: boolean | undefined;
    }, {
        type: "Place";
        id: string;
        symbol?: string | undefined;
        coordinates?: [number, number] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        hideLabel?: boolean | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        strokeOpacity: z.ZodOptional<z.ZodNumber>;
        strokeWidth: z.ZodOptional<z.ZodNumber>;
        strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
        type: z.ZodOptional<z.ZodLiteral<"Path">>;
        coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
        distanceMarker: z.ZodOptional<z.ZodBoolean>;
        routingMode: z.ZodOptional<z.ZodNullable<z.ZodEnum<["driving", "cycling", "walking", "flying"]>>>;
        endCaps: z.ZodOptional<z.ZodBoolean>;
    }, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        imageUrl: z.ZodNullable<z.ZodString>;
    }>, {
        strokeOpacity: z.ZodNumber;
        strokeWidth: z.ZodNumber;
        strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
    }>, {
        type: z.ZodLiteral<"Path">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
        distanceMarker: z.ZodBoolean;
        routingMode: z.ZodNullable<z.ZodEnum<["driving", "cycling", "walking", "flying"]>>;
        endCaps: z.ZodBoolean;
    }>, "type" | "id">>, "strip", z.ZodTypeAny, {
        type: "Path";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    }, {
        type: "Path";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        strokeOpacity: z.ZodOptional<z.ZodNumber>;
        strokeWidth: z.ZodOptional<z.ZodNumber>;
        strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
        type: z.ZodOptional<z.ZodLiteral<"Polygon">>;
        coordinates: z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">>;
        fillOpacity: z.ZodOptional<z.ZodNumber>;
        areaMarker: z.ZodOptional<z.ZodBoolean>;
    }, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        imageUrl: z.ZodNullable<z.ZodString>;
    }>, {
        strokeOpacity: z.ZodNumber;
        strokeWidth: z.ZodNumber;
        strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
    }>, {
        type: z.ZodLiteral<"Polygon">;
        coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
        fillOpacity: z.ZodNumber;
        areaMarker: z.ZodBoolean;
    }>, "type" | "id">>, "strip", z.ZodTypeAny, {
        type: "Polygon";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    }, {
        type: "Polygon";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        imageUrl: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        strokeOpacity: z.ZodOptional<z.ZodNumber>;
        strokeWidth: z.ZodOptional<z.ZodNumber>;
        strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
        type: z.ZodOptional<z.ZodLiteral<"Circle">>;
        center: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
        radius: z.ZodOptional<z.ZodNumber>;
        radiusMarker: z.ZodOptional<z.ZodBoolean>;
        radiusDisplayAngle: z.ZodOptional<z.ZodNumber>;
        radiusDisplayUnit: z.ZodOptional<z.ZodNullable<z.ZodEnum<["meter", "kilometer", "foot", "mile"]>>>;
        fillOpacity: z.ZodOptional<z.ZodNumber>;
    }, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        imageUrl: z.ZodNullable<z.ZodString>;
    }>, {
        strokeOpacity: z.ZodNumber;
        strokeWidth: z.ZodNumber;
        strokeStyle: z.ZodEnum<["solid", "dashed", "dotted"]>;
    }>, {
        type: z.ZodLiteral<"Circle">;
        center: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
        radius: z.ZodNumber;
        radiusMarker: z.ZodBoolean;
        radiusDisplayAngle: z.ZodNumber;
        radiusDisplayUnit: z.ZodNullable<z.ZodEnum<["meter", "kilometer", "foot", "mile"]>>;
        fillOpacity: z.ZodNumber;
    }>, "type" | "id">>, "strip", z.ZodTypeAny, {
        type: "Circle";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        center?: [number, number] | undefined;
        radius?: number | undefined;
        radiusMarker?: boolean | undefined;
        radiusDisplayAngle?: number | undefined;
        radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
    }, {
        type: "Circle";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        center?: [number, number] | undefined;
        radius?: number | undefined;
        radiusMarker?: boolean | undefined;
        radiusDisplayAngle?: number | undefined;
        radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        type: z.ZodOptional<z.ZodLiteral<"Marker">>;
        coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
        opacity: z.ZodOptional<z.ZodNumber>;
        size: z.ZodOptional<z.ZodNumber>;
        zoom: z.ZodOptional<z.ZodNumber>;
    }, Pick<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        type: z.ZodLiteral<"Marker">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
        opacity: z.ZodNumber;
        size: z.ZodNumber;
        zoom: z.ZodNumber;
    }>, "type" | "id">>, "strip", z.ZodTypeAny, {
        type: "Marker";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        zoom?: number | undefined;
    }, {
        type: "Marker";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        zoom?: number | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        type: z.ZodOptional<z.ZodLiteral<"Highlighter">>;
        coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">>;
        renderHoles: z.ZodOptional<z.ZodBoolean>;
        opacity: z.ZodOptional<z.ZodNumber>;
    }, Pick<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        type: z.ZodLiteral<"Highlighter">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
        renderHoles: z.ZodBoolean;
        opacity: z.ZodNumber;
    }>, "type" | "id">>, "strip", z.ZodTypeAny, {
        type: "Highlighter";
        id: string;
        coordinates?: [number, number][][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        renderHoles?: boolean | undefined;
    }, {
        type: "Highlighter";
        id: string;
        coordinates?: [number, number][][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        renderHoles?: boolean | undefined;
    }>, z.ZodObject<Omit<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        position: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
        rotation: z.ZodOptional<z.ZodNumber>;
        scale: z.ZodOptional<z.ZodNumber>;
        zoom: z.ZodOptional<z.ZodNumber>;
        text: z.ZodOptional<z.ZodString>;
        align: z.ZodOptional<z.ZodEnum<["left", "center", "right"]>>;
        style: z.ZodOptional<z.ZodEnum<["italic", "light", "regular", "caps"]>>;
        name: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodLiteral<"Text">>;
    }, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        position: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
        rotation: z.ZodNumber;
        scale: z.ZodNumber;
        zoom: z.ZodNumber;
        text: z.ZodString;
        align: z.ZodEnum<["left", "center", "right"]>;
        style: z.ZodEnum<["italic", "light", "regular", "caps"]>;
        name: z.ZodString;
    }>, {
        type: z.ZodLiteral<"Text">;
    }>, "type" | "id">>, "name">, "strip", z.ZodTypeAny, {
        type: "Text";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        text?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    }, {
        type: "Text";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        text?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    }>, z.ZodObject<Omit<z.objectUtil.extendShape<{
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        color: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        position: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>>;
        rotation: z.ZodOptional<z.ZodNumber>;
        scale: z.ZodOptional<z.ZodNumber>;
        zoom: z.ZodOptional<z.ZodNumber>;
        text: z.ZodOptional<z.ZodString>;
        align: z.ZodOptional<z.ZodEnum<["left", "center", "right"]>>;
        style: z.ZodOptional<z.ZodEnum<["italic", "light", "regular", "caps"]>>;
        name: z.ZodOptional<z.ZodString>;
        type: z.ZodOptional<z.ZodLiteral<"Note">>;
        widthScale: z.ZodOptional<z.ZodNumber>;
    }, Pick<z.objectUtil.extendShape<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        position: z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>;
        rotation: z.ZodNumber;
        scale: z.ZodNumber;
        zoom: z.ZodNumber;
        text: z.ZodString;
        align: z.ZodEnum<["left", "center", "right"]>;
        style: z.ZodEnum<["italic", "light", "regular", "caps"]>;
        name: z.ZodString;
    }>, {
        type: z.ZodLiteral<"Note">;
        widthScale: z.ZodNumber;
    }>, "type" | "id">>, "name">, "strip", z.ZodTypeAny, {
        type: "Note";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        text?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
        widthScale?: number | undefined;
    }, {
        type: "Note";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        text?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
        widthScale?: number | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        type: z.ZodOptional<z.ZodLiteral<"Image">>;
        coordinates: z.ZodOptional<z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">>;
        id: z.ZodOptional<z.ZodString>;
        groupId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        name: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        attributes: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
        interaction: z.ZodOptional<z.ZodOptional<z.ZodEnum<["default", "locked"]>>>;
        imageUrl: z.ZodOptional<z.ZodString>;
        opacity: z.ZodOptional<z.ZodNumber>;
    }, Pick<Omit<z.objectUtil.extendShape<{
        id: z.ZodString;
        groupId: z.ZodNullable<z.ZodString>;
        color: z.ZodString;
        name: z.ZodNullable<z.ZodString>;
        description: z.ZodNullable<z.ZodString>;
        attributes: z.ZodRecord<z.ZodString, z.ZodUnknown>;
        interaction: z.ZodOptional<z.ZodEnum<["default", "locked"]>>;
    }, {
        type: z.ZodLiteral<"Image">;
        coordinates: z.ZodArray<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, "many">;
        imageUrl: z.ZodString;
        opacity: z.ZodNumber;
    }>, "color">, "type" | "id">>, "strip", z.ZodTypeAny, {
        type: "Image";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | undefined;
        opacity?: number | undefined;
    }, {
        type: "Image";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | undefined;
        opacity?: number | undefined;
    }>]>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        type: "Place";
        id: string;
        symbol?: string | undefined;
        coordinates?: [number, number] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        hideLabel?: boolean | undefined;
    } | {
        type: "Path";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    } | {
        type: "Polygon";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    } | {
        type: "Circle";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        center?: [number, number] | undefined;
        radius?: number | undefined;
        radiusMarker?: boolean | undefined;
        radiusDisplayAngle?: number | undefined;
        radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
    } | {
        type: "Marker";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        zoom?: number | undefined;
    } | {
        type: "Highlighter";
        id: string;
        coordinates?: [number, number][][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        renderHoles?: boolean | undefined;
    } | {
        type: "Text";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        text?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    } | {
        type: "Note";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        text?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
        widthScale?: number | undefined;
    } | {
        type: "Image";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | undefined;
        opacity?: number | undefined;
    };
    type: "updateElement";
}, {
    params: {
        type: "Place";
        id: string;
        symbol?: string | undefined;
        coordinates?: [number, number] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        hideLabel?: boolean | undefined;
    } | {
        type: "Path";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    } | {
        type: "Polygon";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    } | {
        type: "Circle";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | null | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        center?: [number, number] | undefined;
        radius?: number | undefined;
        radiusMarker?: boolean | undefined;
        radiusDisplayAngle?: number | undefined;
        radiusDisplayUnit?: "meter" | "kilometer" | "foot" | "mile" | null | undefined;
    } | {
        type: "Marker";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        zoom?: number | undefined;
    } | {
        type: "Highlighter";
        id: string;
        coordinates?: [number, number][][][] | undefined;
        groupId?: string | null | undefined;
        color?: string | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        opacity?: number | undefined;
        renderHoles?: boolean | undefined;
    } | {
        type: "Text";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        text?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    } | {
        type: "Note";
        id: string;
        groupId?: string | null | undefined;
        color?: string | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        zoom?: number | undefined;
        position?: [number, number] | undefined;
        rotation?: number | undefined;
        scale?: number | undefined;
        text?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
        widthScale?: number | undefined;
    } | {
        type: "Image";
        id: string;
        coordinates?: [number, number][][] | undefined;
        groupId?: string | null | undefined;
        name?: string | null | undefined;
        description?: string | null | undefined;
        attributes?: Record<string, unknown> | undefined;
        interaction?: "default" | "locked" | undefined;
        imageUrl?: string | undefined;
        opacity?: number | undefined;
    };
    type: "updateElement";
}>;
declare const DeleteElementMessage: z.ZodObject<{
    type: z.ZodLiteral<"deleteElement">;
    params: z.ZodString;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: string;
    type: "deleteElement";
}, {
    params: string;
    type: "deleteElement";
}>;
type ElementsSchema = {
    methods: {
        getElement: Method<zInfer<typeof GetElementMessage>>;
        getElementGeometry: Method<zInfer<typeof GetElementGeometryMessage>>;
        getElements: Method<zInfer<typeof GetElementsMessage>>;
        getElementGroup: Method<zInfer<typeof GetGroupMessage$1>>;
        getElementGroups: Method<zInfer<typeof GetGroupsMessage$1>>;
        setElementGroupVisibility: Method<zInfer<typeof SetElementGroupVisibilityMessage>>;
        createElement: Method<zInfer<typeof CreateElementMessage>>;
        updateElement: Method<zInfer<typeof UpdateElementMessage>>;
        deleteElement: Method<zInfer<typeof DeleteElementMessage>>;
    };
    listeners: {
        onElementChange: Listener<zInfer<typeof OnElementChangeMessage.shape.options>, ElementChangeCallbackParams>;
        onElementGroupChange: Listener<zInfer<typeof OnElementGroupChangeMessage.shape.options>, ElementGroupChangeCallbackParams>;
        onElementCreate: ListenerNoOptions<ElementChangeCallbackParams>;
        onElementCreateEnd: ListenerNoOptions<{
            element: Element;
        }>;
        onElementDelete: Listener<zInfer<typeof OnElementDeleteMessage.shape.options>, void>;
    };
};

type InteractionsSchema = {
    methods: {};
    listeners: {
        onPointerClick: ListenerNoOptions<MapInteractionEvent>;
        onPointerMove: ListenerNoOptions<MapInteractionEvent>;
    };
};

declare const GetLayerMessage: z.ZodObject<{
    type: z.ZodLiteral<"getLayer">;
    params: z.ZodString;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: string;
    type: "getLayer";
}, {
    params: string;
    type: "getLayer";
}>;
declare const GetLayersMessage: z.ZodObject<{
    type: z.ZodLiteral<"getLayers">;
    params: z.ZodOptional<z.ZodObject<{
        ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        ids?: string[] | undefined;
    }, {
        ids?: string[] | undefined;
    }>>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "getLayers";
    params?: {
        ids?: string[] | undefined;
    } | undefined;
}, {
    type: "getLayers";
    params?: {
        ids?: string[] | undefined;
    } | undefined;
}>;
declare const SetLayerVisibilityMessage: z.ZodObject<{
    type: z.ZodLiteral<"setLayerVisibility">;
    params: z.ZodObject<{
        show: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        hide: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    }, {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    };
    type: "setLayerVisibility";
}, {
    params: {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    };
    type: "setLayerVisibility";
}>;
declare const OnLayerChangeMessage: z.ZodObject<{
    eventName: z.ZodLiteral<"onLayerChange">;
    id: z.ZodString;
    options: z.ZodObject<{
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
    }, {
        id: string;
    }>;
}, "strict", z.ZodTypeAny, {
    options: {
        id: string;
    };
    id: string;
    eventName: "onLayerChange";
}, {
    options: {
        id: string;
    };
    id: string;
    eventName: "onLayerChange";
}>;
declare const SetLayerStyleMessage: z.ZodObject<{
    type: z.ZodLiteral<"setLayerStyle">;
    params: z.ZodObject<{
        id: z.ZodString;
        style: z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>;
    }, "strip", z.ZodTypeAny, {
        id: string;
        style: {} & {
            [k: string]: unknown;
        };
    }, {
        id: string;
        style: {} & {
            [k: string]: unknown;
        };
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        id: string;
        style: {} & {
            [k: string]: unknown;
        };
    };
    type: "setLayerStyle";
}, {
    params: {
        id: string;
        style: {} & {
            [k: string]: unknown;
        };
    };
    type: "setLayerStyle";
}>;
declare const SetLayerLegendVisibilityMessage: z.ZodObject<{
    type: z.ZodLiteral<"setLayerLegendVisibility">;
    params: z.ZodObject<{
        show: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        hide: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    }, {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    };
    type: "setLayerLegendVisibility";
}, {
    params: {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    };
    type: "setLayerLegendVisibility";
}>;
declare const CreateLayersFromGeoJsonMessage: z.ZodObject<{
    type: z.ZodLiteral<"createLayersFromGeoJson">;
    params: z.ZodObject<{
        source: z.ZodUnion<[z.ZodObject<{
            type: z.ZodLiteral<"geoJsonUrl">;
            url: z.ZodString;
            refreshInterval: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        }, {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        }>, z.ZodObject<{
            type: z.ZodLiteral<"geoJsonData">;
            data: z.ZodUnion<[z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>, z.ZodType<ArrayBuffer, z.ZodTypeDef, ArrayBuffer>]>;
        }, "strip", z.ZodTypeAny, {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectOutputType<{}, z.ZodTypeAny, "passthrough">;
        }, {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectInputType<{}, z.ZodTypeAny, "passthrough">;
        }>, z.ZodObject<{
            type: z.ZodLiteral<"geoJsonFile">;
            file: z.ZodType<File, z.ZodTypeDef, File>;
        }, "strip", z.ZodTypeAny, {
            type: "geoJsonFile";
            file: File;
        }, {
            type: "geoJsonFile";
            file: File;
        }>]>;
        name: z.ZodString;
        bounds: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>>;
        caption: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
        geometryStyles: z.ZodOptional<z.ZodObject<{
            Point: z.ZodOptional<z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>>;
            Line: z.ZodOptional<z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>>;
            Polygon: z.ZodOptional<z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>>;
        }, "strip", z.ZodTypeAny, {
            Point?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Polygon?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Line?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        }, {
            Point?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Polygon?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Line?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        source: {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        } | {
            type: "geoJsonFile";
            file: File;
        } | {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectOutputType<{}, z.ZodTypeAny, "passthrough">;
        };
        description?: string | undefined;
        bounds?: [number, number, number, number] | undefined;
        caption?: string | undefined;
        geometryStyles?: {
            Point?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Polygon?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Line?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        } | undefined;
    }, {
        name: string;
        source: {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        } | {
            type: "geoJsonFile";
            file: File;
        } | {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectInputType<{}, z.ZodTypeAny, "passthrough">;
        };
        description?: string | undefined;
        bounds?: [number, number, number, number] | undefined;
        caption?: string | undefined;
        geometryStyles?: {
            Point?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Polygon?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Line?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        } | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        name: string;
        source: {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        } | {
            type: "geoJsonFile";
            file: File;
        } | {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectOutputType<{}, z.ZodTypeAny, "passthrough">;
        };
        description?: string | undefined;
        bounds?: [number, number, number, number] | undefined;
        caption?: string | undefined;
        geometryStyles?: {
            Point?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Polygon?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Line?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        } | undefined;
    };
    type: "createLayersFromGeoJson";
}, {
    params: {
        name: string;
        source: {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        } | {
            type: "geoJsonFile";
            file: File;
        } | {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectInputType<{}, z.ZodTypeAny, "passthrough">;
        };
        description?: string | undefined;
        bounds?: [number, number, number, number] | undefined;
        caption?: string | undefined;
        geometryStyles?: {
            Point?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Polygon?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
            Line?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        } | undefined;
    };
    type: "createLayersFromGeoJson";
}>;
declare const UpdateLayerMessage: z.ZodObject<{
    type: z.ZodLiteral<"updateLayer">;
    params: z.ZodObject<{
        id: z.ZodString;
        style: z.ZodOptional<z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>>;
        shownInLegend: z.ZodOptional<z.ZodBoolean>;
        name: z.ZodOptional<z.ZodString>;
        caption: z.ZodOptional<z.ZodString>;
        description: z.ZodOptional<z.ZodString>;
        bounds: z.ZodOptional<z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>>;
        source: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
            type: z.ZodLiteral<"geoJsonUrl">;
            url: z.ZodString;
            refreshInterval: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        }, {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        }>, z.ZodObject<{
            type: z.ZodLiteral<"geoJsonData">;
            data: z.ZodUnion<[z.ZodObject<{}, "passthrough", z.ZodTypeAny, z.objectOutputType<{}, z.ZodTypeAny, "passthrough">, z.objectInputType<{}, z.ZodTypeAny, "passthrough">>, z.ZodType<ArrayBuffer, z.ZodTypeDef, ArrayBuffer>]>;
        }, "strip", z.ZodTypeAny, {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectOutputType<{}, z.ZodTypeAny, "passthrough">;
        }, {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectInputType<{}, z.ZodTypeAny, "passthrough">;
        }>, z.ZodObject<{
            type: z.ZodLiteral<"geoJsonFile">;
            file: z.ZodType<File, z.ZodTypeDef, File>;
        }, "strip", z.ZodTypeAny, {
            type: "geoJsonFile";
            file: File;
        }, {
            type: "geoJsonFile";
            file: File;
        }>]>>;
    }, "strip", z.ZodTypeAny, {
        id: string;
        name?: string | undefined;
        description?: string | undefined;
        style?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        source?: {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        } | {
            type: "geoJsonFile";
            file: File;
        } | {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectOutputType<{}, z.ZodTypeAny, "passthrough">;
        } | undefined;
        bounds?: [number, number, number, number] | undefined;
        caption?: string | undefined;
        shownInLegend?: boolean | undefined;
    }, {
        id: string;
        name?: string | undefined;
        description?: string | undefined;
        style?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        source?: {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        } | {
            type: "geoJsonFile";
            file: File;
        } | {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectInputType<{}, z.ZodTypeAny, "passthrough">;
        } | undefined;
        bounds?: [number, number, number, number] | undefined;
        caption?: string | undefined;
        shownInLegend?: boolean | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        id: string;
        name?: string | undefined;
        description?: string | undefined;
        style?: z.objectOutputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        source?: {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        } | {
            type: "geoJsonFile";
            file: File;
        } | {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectOutputType<{}, z.ZodTypeAny, "passthrough">;
        } | undefined;
        bounds?: [number, number, number, number] | undefined;
        caption?: string | undefined;
        shownInLegend?: boolean | undefined;
    };
    type: "updateLayer";
}, {
    params: {
        id: string;
        name?: string | undefined;
        description?: string | undefined;
        style?: z.objectInputType<{}, z.ZodTypeAny, "passthrough"> | undefined;
        source?: {
            type: "geoJsonUrl";
            url: string;
            refreshInterval?: number | null | undefined;
        } | {
            type: "geoJsonFile";
            file: File;
        } | {
            type: "geoJsonData";
            data: ArrayBuffer | z.objectInputType<{}, z.ZodTypeAny, "passthrough">;
        } | undefined;
        bounds?: [number, number, number, number] | undefined;
        caption?: string | undefined;
        shownInLegend?: boolean | undefined;
    };
    type: "updateLayer";
}>;
declare const DeleteLayerMessage: z.ZodObject<{
    type: z.ZodLiteral<"deleteLayer">;
    params: z.ZodString;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: string;
    type: "deleteLayer";
}, {
    params: string;
    type: "deleteLayer";
}>;
declare const GetGroupMessage: z.ZodObject<{
    type: z.ZodLiteral<"getLayerGroup">;
    params: z.ZodString;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: string;
    type: "getLayerGroup";
}, {
    params: string;
    type: "getLayerGroup";
}>;
declare const GetGroupsMessage: z.ZodObject<{
    type: z.ZodLiteral<"getLayerGroups">;
    params: z.ZodOptional<z.ZodObject<{
        ids: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        ids?: string[] | undefined;
    }, {
        ids?: string[] | undefined;
    }>>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "getLayerGroups";
    params?: {
        ids?: string[] | undefined;
    } | undefined;
}, {
    type: "getLayerGroups";
    params?: {
        ids?: string[] | undefined;
    } | undefined;
}>;
declare const SetLayerGroupVisibilityMessage: z.ZodObject<{
    type: z.ZodLiteral<"setLayerGroupVisibility">;
    params: z.ZodObject<{
        show: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        hide: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    }, {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    };
    type: "setLayerGroupVisibility";
}, {
    params: {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    };
    type: "setLayerGroupVisibility";
}>;
declare const SetLayerGroupLegendVisibilityMessage: z.ZodObject<{
    type: z.ZodLiteral<"setLayerGroupLegendVisibility">;
    params: z.ZodObject<{
        show: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        hide: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    }, {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    };
    type: "setLayerGroupLegendVisibility";
}, {
    params: {
        show?: string[] | undefined;
        hide?: string[] | undefined;
    };
    type: "setLayerGroupLegendVisibility";
}>;
declare const OnLayerGroupChangeMessage: z.ZodObject<{
    eventName: z.ZodLiteral<"onLayerGroupChange">;
    id: z.ZodString;
    options: z.ZodObject<{
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
    }, {
        id: string;
    }>;
}, "strict", z.ZodTypeAny, {
    options: {
        id: string;
    };
    id: string;
    eventName: "onLayerGroupChange";
}, {
    options: {
        id: string;
    };
    id: string;
    eventName: "onLayerGroupChange";
}>;
declare const GetLegendItemMessage: z.ZodObject<{
    type: z.ZodLiteral<"getLegendItem">;
    params: z.ZodObject<{
        id: z.ZodString;
        layerId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        layerId: string;
    }, {
        id: string;
        layerId: string;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        id: string;
        layerId: string;
    };
    type: "getLegendItem";
}, {
    params: {
        id: string;
        layerId: string;
    };
    type: "getLegendItem";
}>;
declare const GetLegendItemsMessage: z.ZodObject<{
    type: z.ZodLiteral<"getLegendItems">;
    params: z.ZodOptional<z.ZodObject<{
        ids: z.ZodOptional<z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            layerId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            id: string;
            layerId: string;
        }, {
            id: string;
            layerId: string;
        }>, "many">>;
        layerIds: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        ids?: {
            id: string;
            layerId: string;
        }[] | undefined;
        layerIds?: string[] | undefined;
    }, {
        ids?: {
            id: string;
            layerId: string;
        }[] | undefined;
        layerIds?: string[] | undefined;
    }>>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "getLegendItems";
    params?: {
        ids?: {
            id: string;
            layerId: string;
        }[] | undefined;
        layerIds?: string[] | undefined;
    } | undefined;
}, {
    type: "getLegendItems";
    params?: {
        ids?: {
            id: string;
            layerId: string;
        }[] | undefined;
        layerIds?: string[] | undefined;
    } | undefined;
}>;
declare const OnLegendItemChangeMessage: z.ZodObject<{
    eventName: z.ZodLiteral<"onLegendItemChange">;
    id: z.ZodString;
    options: z.ZodObject<{
        id: z.ZodString;
        layerId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
        layerId: string;
    }, {
        id: string;
        layerId: string;
    }>;
}, "strict", z.ZodTypeAny, {
    options: {
        id: string;
        layerId: string;
    };
    id: string;
    eventName: "onLegendItemChange";
}, {
    options: {
        id: string;
        layerId: string;
    };
    id: string;
    eventName: "onLegendItemChange";
}>;
declare const SetLegendItemVisibilityMessage: z.ZodObject<{
    type: z.ZodLiteral<"setLegendItemVisibility">;
    params: z.ZodObject<{
        show: z.ZodOptional<z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            layerId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            id: string;
            layerId: string;
        }, {
            id: string;
            layerId: string;
        }>, "many">>;
        hide: z.ZodOptional<z.ZodArray<z.ZodObject<{
            id: z.ZodString;
            layerId: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            id: string;
            layerId: string;
        }, {
            id: string;
            layerId: string;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        show?: {
            id: string;
            layerId: string;
        }[] | undefined;
        hide?: {
            id: string;
            layerId: string;
        }[] | undefined;
    }, {
        show?: {
            id: string;
            layerId: string;
        }[] | undefined;
        hide?: {
            id: string;
            layerId: string;
        }[] | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        show?: {
            id: string;
            layerId: string;
        }[] | undefined;
        hide?: {
            id: string;
            layerId: string;
        }[] | undefined;
    };
    type: "setLegendItemVisibility";
}, {
    params: {
        show?: {
            id: string;
            layerId: string;
        }[] | undefined;
        hide?: {
            id: string;
            layerId: string;
        }[] | undefined;
    };
    type: "setLegendItemVisibility";
}>;
declare const GetFiltersMessage: z.ZodObject<{
    type: z.ZodLiteral<"getLayerFilters">;
    params: z.ZodString;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: string;
    type: "getLayerFilters";
}, {
    params: string;
    type: "getLayerFilters";
}>;
declare const SetFiltersMessage: z.ZodObject<{
    type: z.ZodLiteral<"setLayerFilters">;
    params: z.ZodObject<{
        layerId: z.ZodString;
        filters: z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>;
        note: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        filters: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null;
        layerId: string;
        note?: string | undefined;
    }, {
        filters: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null;
        layerId: string;
        note?: string | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        filters: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null;
        layerId: string;
        note?: string | undefined;
    };
    type: "setLayerFilters";
}, {
    params: {
        filters: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null;
        layerId: string;
        note?: string | undefined;
    };
    type: "setLayerFilters";
}>;
declare const OnLayerFiltersChangeMessage: z.ZodObject<{
    eventName: z.ZodLiteral<"onLayerFiltersChange">;
    id: z.ZodString;
    options: z.ZodObject<{
        layerId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        layerId: string;
    }, {
        layerId: string;
    }>;
}, "strict", z.ZodTypeAny, {
    options: {
        layerId: string;
    };
    id: string;
    eventName: "onLayerFiltersChange";
}, {
    options: {
        layerId: string;
    };
    id: string;
    eventName: "onLayerFiltersChange";
}>;
declare const GetLayerBoundariesMessage: z.ZodObject<{
    type: z.ZodLiteral<"getLayerBoundaries">;
    params: z.ZodString;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: string;
    type: "getLayerBoundaries";
}, {
    params: string;
    type: "getLayerBoundaries";
}>;
declare const SetLayerBoundaryMessage: z.ZodObject<{
    type: z.ZodLiteral<"setLayerBoundary">;
    params: z.ZodObject<{
        layerIds: z.ZodArray<z.ZodString, "many">;
        boundary: z.ZodNullable<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
            type: z.ZodLiteral<"Polygon">;
            coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "Polygon";
            coordinates: [number, number][][];
        }, {
            type: "Polygon";
            coordinates: [number, number][][];
        }>, z.ZodObject<{
            type: z.ZodLiteral<"MultiPolygon">;
            coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
    }, "strip", z.ZodTypeAny, {
        boundary: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | null;
        layerIds: string[];
    }, {
        boundary: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | null;
        layerIds: string[];
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        boundary: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | null;
        layerIds: string[];
    };
    type: "setLayerBoundary";
}, {
    params: {
        boundary: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | null;
        layerIds: string[];
    };
    type: "setLayerBoundary";
}>;
declare const OnLayerBoundariesChangeMessage: z.ZodObject<{
    eventName: z.ZodLiteral<"onLayerBoundariesChange">;
    id: z.ZodString;
    options: z.ZodObject<{
        layerId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        layerId: string;
    }, {
        layerId: string;
    }>;
}, "strict", z.ZodTypeAny, {
    options: {
        layerId: string;
    };
    id: string;
    eventName: "onLayerBoundariesChange";
}, {
    options: {
        layerId: string;
    };
    id: string;
    eventName: "onLayerBoundariesChange";
}>;
declare const GetRenderedFeaturesMessage: z.ZodObject<{
    type: z.ZodLiteral<"getRenderedFeatures">;
    params: z.ZodOptional<z.ZodObject<{
        layerIds: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        areaQuery: z.ZodOptional<z.ZodUnion<[z.ZodObject<{
            coordinates: z.ZodObject<{
                latitude: z.ZodNumber;
                longitude: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                latitude: number;
                longitude: number;
            }, {
                latitude: number;
                longitude: number;
            }>;
        }, "strip", z.ZodTypeAny, {
            coordinates: {
                latitude: number;
                longitude: number;
            };
        }, {
            coordinates: {
                latitude: number;
                longitude: number;
            };
        }>, z.ZodObject<{
            boundary: z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>;
        }, "strip", z.ZodTypeAny, {
            boundary: [number, number, number, number];
        }, {
            boundary: [number, number, number, number];
        }>]>>;
    }, "strip", z.ZodTypeAny, {
        layerIds?: string[] | undefined;
        areaQuery?: {
            coordinates: {
                latitude: number;
                longitude: number;
            };
        } | {
            boundary: [number, number, number, number];
        } | undefined;
    }, {
        layerIds?: string[] | undefined;
        areaQuery?: {
            coordinates: {
                latitude: number;
                longitude: number;
            };
        } | {
            boundary: [number, number, number, number];
        } | undefined;
    }>>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "getRenderedFeatures";
    params?: {
        layerIds?: string[] | undefined;
        areaQuery?: {
            coordinates: {
                latitude: number;
                longitude: number;
            };
        } | {
            boundary: [number, number, number, number];
        } | undefined;
    } | undefined;
}, {
    type: "getRenderedFeatures";
    params?: {
        layerIds?: string[] | undefined;
        areaQuery?: {
            coordinates: {
                latitude: number;
                longitude: number;
            };
        } | {
            boundary: [number, number, number, number];
        } | undefined;
    } | undefined;
}>;
declare const GetFeatureMessage: z.ZodObject<{
    type: z.ZodLiteral<"getFeature">;
    params: z.ZodObject<{
        id: z.ZodUnion<[z.ZodString, z.ZodNumber]>;
        layerId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string | number;
        layerId: string;
    }, {
        id: string | number;
        layerId: string;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        id: string | number;
        layerId: string;
    };
    type: "getFeature";
}, {
    params: {
        id: string | number;
        layerId: string;
    };
    type: "getFeature";
}>;
declare const GetFeaturesMessage: z.ZodObject<{
    type: z.ZodLiteral<"getFeatures">;
    params: z.ZodObject<{
        layerId: z.ZodString;
        filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
        sorting: z.ZodOptional<z.ZodObject<{
            attribute: z.ZodString;
            direction: z.ZodEnum<["asc", "desc"]>;
        }, "strip", z.ZodTypeAny, {
            attribute: string;
            direction: "asc" | "desc";
        }, {
            attribute: string;
            direction: "asc" | "desc";
        }>>;
        boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
            type: z.ZodLiteral<"Polygon">;
            coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "Polygon";
            coordinates: [number, number][][];
        }, {
            type: "Polygon";
            coordinates: [number, number][][];
        }>, z.ZodObject<{
            type: z.ZodLiteral<"MultiPolygon">;
            coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
        search: z.ZodOptional<z.ZodString>;
        pagination: z.ZodOptional<z.ZodNullable<z.ZodOptional<z.ZodString>>>;
    }, "strip", z.ZodTypeAny, {
        layerId: string;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        sorting?: {
            attribute: string;
            direction: "asc" | "desc";
        } | undefined;
        search?: string | undefined;
        pagination?: string | null | undefined;
    }, {
        layerId: string;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        sorting?: {
            attribute: string;
            direction: "asc" | "desc";
        } | undefined;
        search?: string | undefined;
        pagination?: string | null | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        layerId: string;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        sorting?: {
            attribute: string;
            direction: "asc" | "desc";
        } | undefined;
        search?: string | undefined;
        pagination?: string | null | undefined;
    };
    type: "getFeatures";
}, {
    params: {
        layerId: string;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        sorting?: {
            attribute: string;
            direction: "asc" | "desc";
        } | undefined;
        search?: string | undefined;
        pagination?: string | null | undefined;
    };
    type: "getFeatures";
}>;
declare const GetGeoJsonFeatureMessage: z.ZodObject<{
    type: z.ZodLiteral<"getGeoJsonFeature">;
    params: z.ZodObject<{
        id: z.ZodUnion<[z.ZodString, z.ZodNumber]>;
        layerId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string | number;
        layerId: string;
    }, {
        id: string | number;
        layerId: string;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        id: string | number;
        layerId: string;
    };
    type: "getGeoJsonFeature";
}, {
    params: {
        id: string | number;
        layerId: string;
    };
    type: "getGeoJsonFeature";
}>;
declare const GetLayerCategoriesMessage: z.ZodObject<{
    type: z.ZodLiteral<"getCategoryData">;
    params: z.ZodObject<{
        layerId: z.ZodString;
        attribute: z.ZodString;
        limit: z.ZodOptional<z.ZodNumber>;
        boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
            type: z.ZodLiteral<"Polygon">;
            coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "Polygon";
            coordinates: [number, number][][];
        }, {
            type: "Polygon";
            coordinates: [number, number][][];
        }>, z.ZodObject<{
            type: z.ZodLiteral<"MultiPolygon">;
            coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
        filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
        values: z.ZodOptional<z.ZodObject<{
            boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
                type: z.ZodLiteral<"Polygon">;
                coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
            }, "strip", z.ZodTypeAny, {
                type: "Polygon";
                coordinates: [number, number][][];
            }, {
                type: "Polygon";
                coordinates: [number, number][][];
            }>, z.ZodObject<{
                type: z.ZodLiteral<"MultiPolygon">;
                coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
            }, "strip", z.ZodTypeAny, {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            }, {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
            filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
            aggregation: z.ZodOptional<z.ZodObject<{
                method: z.ZodEnum<["avg", "max", "min", "sum", "median"]>;
                attribute: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            }, {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            }>>;
        }, "strip", z.ZodTypeAny, {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        }, {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        attribute: string;
        layerId: string;
        values?: {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        } | undefined;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        limit?: number | undefined;
    }, {
        attribute: string;
        layerId: string;
        values?: {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        } | undefined;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        limit?: number | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        attribute: string;
        layerId: string;
        values?: {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        } | undefined;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        limit?: number | undefined;
    };
    type: "getCategoryData";
}, {
    params: {
        attribute: string;
        layerId: string;
        values?: {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        } | undefined;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
        limit?: number | undefined;
    };
    type: "getCategoryData";
}>;
declare const GetLayerHistogramMessage: z.ZodObject<{
    type: z.ZodLiteral<"getHistogramData">;
    params: z.ZodObject<{
        layerId: z.ZodString;
        attribute: z.ZodString;
        steps: z.ZodUnion<[z.ZodObject<{
            type: z.ZodLiteral<"equal-intervals">;
            count: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            type: "equal-intervals";
            count: number;
        }, {
            type: "equal-intervals";
            count: number;
        }>, z.ZodObject<{
            type: z.ZodLiteral<"time-interval">;
            interval: z.ZodEnum<["hour", "day", "week", "month", "year"]>;
        }, "strip", z.ZodTypeAny, {
            type: "time-interval";
            interval: "hour" | "day" | "week" | "month" | "year";
        }, {
            type: "time-interval";
            interval: "hour" | "day" | "week" | "month" | "year";
        }>, z.ZodArray<z.ZodNumber, "many">]>;
        boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
            type: z.ZodLiteral<"Polygon">;
            coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "Polygon";
            coordinates: [number, number][][];
        }, {
            type: "Polygon";
            coordinates: [number, number][][];
        }>, z.ZodObject<{
            type: z.ZodLiteral<"MultiPolygon">;
            coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
        filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
        values: z.ZodOptional<z.ZodObject<{
            boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
                type: z.ZodLiteral<"Polygon">;
                coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
            }, "strip", z.ZodTypeAny, {
                type: "Polygon";
                coordinates: [number, number][][];
            }, {
                type: "Polygon";
                coordinates: [number, number][][];
            }>, z.ZodObject<{
                type: z.ZodLiteral<"MultiPolygon">;
                coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
            }, "strip", z.ZodTypeAny, {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            }, {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
            filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
            aggregation: z.ZodOptional<z.ZodObject<{
                method: z.ZodEnum<["avg", "max", "min", "sum", "median"]>;
                attribute: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            }, {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            }>>;
        }, "strip", z.ZodTypeAny, {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        }, {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        attribute: string;
        layerId: string;
        steps: number[] | {
            type: "equal-intervals";
            count: number;
        } | {
            type: "time-interval";
            interval: "hour" | "day" | "week" | "month" | "year";
        };
        values?: {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        } | undefined;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    }, {
        attribute: string;
        layerId: string;
        steps: number[] | {
            type: "equal-intervals";
            count: number;
        } | {
            type: "time-interval";
            interval: "hour" | "day" | "week" | "month" | "year";
        };
        values?: {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        } | undefined;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        attribute: string;
        layerId: string;
        steps: number[] | {
            type: "equal-intervals";
            count: number;
        } | {
            type: "time-interval";
            interval: "hour" | "day" | "week" | "month" | "year";
        };
        values?: {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        } | undefined;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    };
    type: "getHistogramData";
}, {
    params: {
        attribute: string;
        layerId: string;
        steps: number[] | {
            type: "equal-intervals";
            count: number;
        } | {
            type: "time-interval";
            interval: "hour" | "day" | "week" | "month" | "year";
        };
        values?: {
            boundary?: [number, number, number, number] | [number, number][] | {
                type: "Polygon";
                coordinates: [number, number][][];
            } | {
                type: "MultiPolygon";
                coordinates: [number, number][][][];
            } | undefined;
            filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
            aggregation?: {
                attribute: string;
                method: "avg" | "max" | "min" | "sum" | "median";
            } | undefined;
        } | undefined;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    };
    type: "getHistogramData";
}>;
declare const GetLayerCalculationMessage: z.ZodObject<{
    type: z.ZodLiteral<"getAggregates">;
    params: z.ZodObject<{
        layerId: z.ZodString;
        boundary: z.ZodOptional<z.ZodUnion<[z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>, z.ZodObject<{
            type: z.ZodLiteral<"Polygon">;
            coordinates: z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "Polygon";
            coordinates: [number, number][][];
        }, {
            type: "Polygon";
            coordinates: [number, number][][];
        }>, z.ZodObject<{
            type: z.ZodLiteral<"MultiPolygon">;
            coordinates: z.ZodArray<z.ZodArray<z.ZodEffects<z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">, [number, number][], [number, number][]>, "many">, "many">;
        }, "strip", z.ZodTypeAny, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }, {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        }>, z.ZodArray<z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, "many">]>>;
        filters: z.ZodOptional<z.ZodUnion<[z.ZodType<FilterTernary, z.ZodTypeDef, FilterTernary>, z.ZodUnion<[z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["in", "ni"]>, z.ZodUnion<[z.ZodArray<z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>, "many">, z.ZodNull]>], null>, z.ZodTuple<[z.ZodUnion<[z.ZodString, z.ZodNull]>, z.ZodEnum<["lt", "gt", "le", "ge", "eq", "ne", "cn", "nc", "is", "isnt"]>, z.ZodUnion<[z.ZodNumber, z.ZodString, z.ZodBoolean, z.ZodNull]>], null>]>, z.ZodNull, z.ZodBoolean]>>;
        aggregation: z.ZodObject<{
            methods: z.ZodArray<z.ZodUnion<[z.ZodEnum<["avg", "max", "min", "sum", "median"]>, z.ZodLiteral<"count">]>, "many">;
            attribute: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
            attribute?: string | undefined;
        }, {
            methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
            attribute?: string | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        aggregation: {
            methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
            attribute?: string | undefined;
        };
        layerId: string;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    }, {
        aggregation: {
            methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
            attribute?: string | undefined;
        };
        layerId: string;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        aggregation: {
            methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
            attribute?: string | undefined;
        };
        layerId: string;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    };
    type: "getAggregates";
}, {
    params: {
        aggregation: {
            methods: ("avg" | "max" | "min" | "sum" | "median" | "count")[];
            attribute?: string | undefined;
        };
        layerId: string;
        boundary?: [number, number, number, number] | [number, number][] | {
            type: "Polygon";
            coordinates: [number, number][][];
        } | {
            type: "MultiPolygon";
            coordinates: [number, number][][][];
        } | undefined;
        filters?: boolean | [string | null, "in" | "ni", (string | number | boolean | null)[] | null] | [string | null, "lt" | "gt" | "le" | "ge" | "eq" | "ne" | "cn" | "nc" | "is" | "isnt", string | number | boolean | null] | FilterTernary | null | undefined;
    };
    type: "getAggregates";
}>;
declare const GetLayerSchemaMessage: z.ZodObject<{
    type: z.ZodLiteral<"getLayerSchema">;
    params: z.ZodString;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: string;
    type: "getLayerSchema";
}, {
    params: string;
    type: "getLayerSchema";
}>;
type LayersSchema = {
    methods: {
        getLayer: Method<zInfer<typeof GetLayerMessage>>;
        getLayers: Method<zInfer<typeof GetLayersMessage>>;
        setLayerVisibility: Method<zInfer<typeof SetLayerVisibilityMessage>>;
        setLayerStyle: Method<zInfer<typeof SetLayerStyleMessage>>;
        setLayerLegendVisibility: Method<zInfer<typeof SetLayerLegendVisibilityMessage>>;
        createLayersFromGeoJson: Method<zInfer<typeof CreateLayersFromGeoJsonMessage>>;
        updateLayer: Method<zInfer<typeof UpdateLayerMessage>>;
        deleteLayer: Method<zInfer<typeof DeleteLayerMessage>>;
        getLayerGroup: Method<zInfer<typeof GetGroupMessage>>;
        getLayerGroups: Method<zInfer<typeof GetGroupsMessage>>;
        setLayerGroupVisibility: Method<zInfer<typeof SetLayerGroupVisibilityMessage>>;
        setLayerGroupLegendVisibility: Method<zInfer<typeof SetLayerGroupLegendVisibilityMessage>>;
        getLegendItem: Method<zInfer<typeof GetLegendItemMessage>>;
        getLegendItems: Method<zInfer<typeof GetLegendItemsMessage>>;
        setLegendItemVisibility: Method<zInfer<typeof SetLegendItemVisibilityMessage>>;
        getLayerFilters: Method<zInfer<typeof GetFiltersMessage>>;
        setLayerFilters: Method<zInfer<typeof SetFiltersMessage>>;
        getRenderedFeatures: Method<zInfer<typeof GetRenderedFeaturesMessage>>;
        getFeature: Method<zInfer<typeof GetFeatureMessage>>;
        getGeoJsonFeature: Method<zInfer<typeof GetGeoJsonFeatureMessage>>;
        getLayerBoundaries: Method<zInfer<typeof GetLayerBoundariesMessage>>;
        setLayerBoundary: Method<zInfer<typeof SetLayerBoundaryMessage>>;
        getFeatures: Method<zInfer<typeof GetFeaturesMessage>>;
        getCategoryData: Method<zInfer<typeof GetLayerCategoriesMessage>>;
        getHistogramData: Method<zInfer<typeof GetLayerHistogramMessage>>;
        getAggregates: Method<zInfer<typeof GetLayerCalculationMessage>>;
        getLayerSchema: Method<zInfer<typeof GetLayerSchemaMessage>>;
    };
    listeners: {
        onLayerChange: Listener<zInfer<typeof OnLayerChangeMessage.shape.options>, LayerChangeCallbackParams>;
        onLayerGroupChange: Listener<zInfer<typeof OnLayerGroupChangeMessage.shape.options>, LayerGroupChangeCallbackParams>;
        onLegendItemChange: Listener<zInfer<typeof OnLegendItemChangeMessage.shape.options>, LegendItemChangeCallbackParams>;
        onLayerFiltersChange: Listener<zInfer<typeof OnLayerFiltersChangeMessage.shape.options>, LayerFilters>;
        onLayerBoundariesChange: Listener<zInfer<typeof OnLayerBoundariesChangeMessage.shape.options>, LayerBoundaries | null>;
    };
};

declare const GetMapDetailsMessage: z.ZodObject<{
    type: z.ZodLiteral<"getMapDetails">;
    params: z.ZodUndefined;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "getMapDetails";
    params?: undefined;
}, {
    type: "getMapDetails";
    params?: undefined;
}>;
type MiscSchema = {
    methods: {
        getMapDetails: Method<zInfer<typeof GetMapDetailsMessage>>;
    };
    listeners: {};
};

declare const GetSelectionMessage: z.ZodObject<{
    type: z.ZodLiteral<"getSelection">;
    params: z.ZodUndefined;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "getSelection";
    params?: undefined;
}, {
    type: "getSelection";
    params?: undefined;
}>;
declare const SelectFeatureMessage: z.ZodObject<{
    type: z.ZodLiteral<"selectFeature">;
    params: z.ZodObject<{
        id: z.ZodUnion<[z.ZodString, z.ZodNumber]>;
        layerId: z.ZodString;
        showPopup: z.ZodOptional<z.ZodBoolean>;
        fitViewport: z.ZodOptional<z.ZodUnion<[z.ZodBoolean, z.ZodObject<{
            maxZoom: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            maxZoom: number;
        }, {
            maxZoom: number;
        }>]>>;
    }, "strip", z.ZodTypeAny, {
        id: string | number;
        layerId: string;
        showPopup?: boolean | undefined;
        fitViewport?: boolean | {
            maxZoom: number;
        } | undefined;
    }, {
        id: string | number;
        layerId: string;
        showPopup?: boolean | undefined;
        fitViewport?: boolean | {
            maxZoom: number;
        } | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        id: string | number;
        layerId: string;
        showPopup?: boolean | undefined;
        fitViewport?: boolean | {
            maxZoom: number;
        } | undefined;
    };
    type: "selectFeature";
}, {
    params: {
        id: string | number;
        layerId: string;
        showPopup?: boolean | undefined;
        fitViewport?: boolean | {
            maxZoom: number;
        } | undefined;
    };
    type: "selectFeature";
}>;
declare const ClearSelectionMessage: z.ZodObject<{
    type: z.ZodLiteral<"clearSelection">;
    params: z.ZodOptional<z.ZodObject<{
        features: z.ZodOptional<z.ZodBoolean>;
        elements: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        features?: boolean | undefined;
        elements?: boolean | undefined;
    }, {
        features?: boolean | undefined;
        elements?: boolean | undefined;
    }>>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "clearSelection";
    params?: {
        features?: boolean | undefined;
        elements?: boolean | undefined;
    } | undefined;
}, {
    type: "clearSelection";
    params?: {
        features?: boolean | undefined;
        elements?: boolean | undefined;
    } | undefined;
}>;
type SelectionSchema = {
    methods: {
        getSelection: Method<zInfer<typeof GetSelectionMessage>>;
        selectFeature: Method<zInfer<typeof SelectFeatureMessage>>;
        clearSelection: Method<zInfer<typeof ClearSelectionMessage>>;
    };
    listeners: {
        onSelectionChange: ListenerNoOptions<{
            selection: Array<EntityNode>;
        }>;
    };
};

declare const SetToolMessage: z.ZodObject<{
    type: z.ZodLiteral<"setTool">;
    params: z.ZodNullable<z.ZodEnum<["pin", "line", "route", "polygon", "circle", "marker", "highlighter", "text", "note", "link"]>>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: "text" | "note" | "pin" | "line" | "route" | "polygon" | "circle" | "marker" | "highlighter" | "link" | null;
    type: "setTool";
}, {
    params: "text" | "note" | "pin" | "line" | "route" | "polygon" | "circle" | "marker" | "highlighter" | "link" | null;
    type: "setTool";
}>;
declare const GetToolMessage: z.ZodObject<{
    type: z.ZodLiteral<"getTool">;
    params: z.ZodUndefined;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "getTool";
    params?: undefined;
}, {
    type: "getTool";
    params?: undefined;
}>;
declare const SetToolSettingsMessage: z.ZodObject<{
    type: z.ZodLiteral<"setToolSettings">;
    params: z.ZodDiscriminatedUnion<"tool", [z.ZodObject<z.objectUtil.extendShape<{
        symbol: z.ZodOptional<z.ZodString>;
        color: z.ZodOptional<z.ZodString>;
        frame: z.ZodOptional<z.ZodNullable<z.ZodEnum<["frame-circle", "frame-square"]>>>;
        afterCreation: z.ZodOptional<z.ZodEnum<["enter name", "add another", "select"]>>;
    }, {
        tool: z.ZodLiteral<"pin">;
    }>, "strip", z.ZodTypeAny, {
        tool: "pin";
        symbol?: string | undefined;
        color?: string | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        afterCreation?: "enter name" | "add another" | "select" | undefined;
    }, {
        tool: "pin";
        symbol?: string | undefined;
        color?: string | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        afterCreation?: "enter name" | "add another" | "select" | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        color: z.ZodOptional<z.ZodString>;
        strokeOpacity: z.ZodOptional<z.ZodNumber>;
        strokeWidth: z.ZodOptional<z.ZodNumber>;
        strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
        distanceMarker: z.ZodOptional<z.ZodBoolean>;
    }, {
        tool: z.ZodLiteral<"line">;
    }>, "strip", z.ZodTypeAny, {
        tool: "line";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
    }, {
        tool: "line";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        color: z.ZodOptional<z.ZodString>;
        strokeOpacity: z.ZodOptional<z.ZodNumber>;
        strokeWidth: z.ZodOptional<z.ZodNumber>;
        strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
        distanceMarker: z.ZodOptional<z.ZodBoolean>;
        routingMode: z.ZodOptional<z.ZodNullable<z.ZodEnum<["driving", "cycling", "walking", "flying"]>>>;
        endCaps: z.ZodOptional<z.ZodBoolean>;
    }, {
        tool: z.ZodLiteral<"route">;
    }>, "strip", z.ZodTypeAny, {
        tool: "route";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    }, {
        tool: "route";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        color: z.ZodOptional<z.ZodString>;
        strokeOpacity: z.ZodOptional<z.ZodNumber>;
        strokeWidth: z.ZodOptional<z.ZodNumber>;
        strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
        fillOpacity: z.ZodOptional<z.ZodNumber>;
        areaMarker: z.ZodOptional<z.ZodBoolean>;
    }, {
        tool: z.ZodLiteral<"polygon">;
    }>, "strip", z.ZodTypeAny, {
        tool: "polygon";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    }, {
        tool: "polygon";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        color: z.ZodOptional<z.ZodString>;
        strokeOpacity: z.ZodOptional<z.ZodNumber>;
        strokeWidth: z.ZodOptional<z.ZodNumber>;
        strokeStyle: z.ZodOptional<z.ZodEnum<["solid", "dashed", "dotted"]>>;
        fillOpacity: z.ZodOptional<z.ZodNumber>;
        radiusMarker: z.ZodOptional<z.ZodBoolean>;
    }, {
        tool: z.ZodLiteral<"circle">;
    }>, "strip", z.ZodTypeAny, {
        tool: "circle";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        radiusMarker?: boolean | undefined;
    }, {
        tool: "circle";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        radiusMarker?: boolean | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        color: z.ZodOptional<z.ZodString>;
        opacity: z.ZodOptional<z.ZodNumber>;
        size: z.ZodOptional<z.ZodNumber>;
    }, {
        tool: z.ZodLiteral<"marker">;
    }>, "strip", z.ZodTypeAny, {
        tool: "marker";
        color?: string | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
    }, {
        tool: "marker";
        color?: string | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        color: z.ZodOptional<z.ZodString>;
        opacity: z.ZodOptional<z.ZodNumber>;
        renderHoles: z.ZodOptional<z.ZodBoolean>;
        size: z.ZodOptional<z.ZodNumber>;
    }, {
        tool: z.ZodLiteral<"highlighter">;
    }>, "strip", z.ZodTypeAny, {
        tool: "highlighter";
        color?: string | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        renderHoles?: boolean | undefined;
    }, {
        tool: "highlighter";
        color?: string | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        renderHoles?: boolean | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        color: z.ZodOptional<z.ZodString>;
        align: z.ZodOptional<z.ZodEnum<["left", "center", "right"]>>;
        style: z.ZodOptional<z.ZodEnum<["italic", "light", "regular", "caps"]>>;
    }, {
        tool: z.ZodLiteral<"text">;
    }>, "strip", z.ZodTypeAny, {
        tool: "text";
        color?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    }, {
        tool: "text";
        color?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    }>, z.ZodObject<z.objectUtil.extendShape<{
        color: z.ZodOptional<z.ZodString>;
        align: z.ZodOptional<z.ZodEnum<["left", "center", "right"]>>;
        style: z.ZodOptional<z.ZodEnum<["italic", "light", "regular", "caps"]>>;
    }, {
        tool: z.ZodLiteral<"note">;
    }>, "strip", z.ZodTypeAny, {
        tool: "note";
        color?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    }, {
        tool: "note";
        color?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    }>]>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        tool: "pin";
        symbol?: string | undefined;
        color?: string | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        afterCreation?: "enter name" | "add another" | "select" | undefined;
    } | {
        tool: "line";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
    } | {
        tool: "route";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    } | {
        tool: "polygon";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    } | {
        tool: "circle";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        radiusMarker?: boolean | undefined;
    } | {
        tool: "marker";
        color?: string | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
    } | {
        tool: "highlighter";
        color?: string | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        renderHoles?: boolean | undefined;
    } | {
        tool: "text";
        color?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    } | {
        tool: "note";
        color?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    };
    type: "setToolSettings";
}, {
    params: {
        tool: "pin";
        symbol?: string | undefined;
        color?: string | undefined;
        frame?: "frame-circle" | "frame-square" | null | undefined;
        afterCreation?: "enter name" | "add another" | "select" | undefined;
    } | {
        tool: "line";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
    } | {
        tool: "route";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        distanceMarker?: boolean | undefined;
        routingMode?: "driving" | "cycling" | "walking" | "flying" | null | undefined;
        endCaps?: boolean | undefined;
    } | {
        tool: "polygon";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        areaMarker?: boolean | undefined;
    } | {
        tool: "circle";
        color?: string | undefined;
        strokeOpacity?: number | undefined;
        strokeWidth?: number | undefined;
        strokeStyle?: "solid" | "dashed" | "dotted" | undefined;
        fillOpacity?: number | undefined;
        radiusMarker?: boolean | undefined;
    } | {
        tool: "marker";
        color?: string | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
    } | {
        tool: "highlighter";
        color?: string | undefined;
        opacity?: number | undefined;
        size?: number | undefined;
        renderHoles?: boolean | undefined;
    } | {
        tool: "text";
        color?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    } | {
        tool: "note";
        color?: string | undefined;
        align?: "center" | "left" | "right" | undefined;
        style?: "italic" | "light" | "regular" | "caps" | undefined;
    };
    type: "setToolSettings";
}>;
declare const GetToolSettingsMessage: z.ZodObject<{
    type: z.ZodLiteral<"getToolSettings">;
    params: z.ZodEnum<["pin", "line", "route", "polygon", "circle", "marker", "highlighter", "text", "note"]>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: "text" | "note" | "pin" | "line" | "route" | "polygon" | "circle" | "marker" | "highlighter";
    type: "getToolSettings";
}, {
    params: "text" | "note" | "pin" | "line" | "route" | "polygon" | "circle" | "marker" | "highlighter";
    type: "getToolSettings";
}>;
type ToolsSchema = {
    methods: {
        setTool: Method<zInfer<typeof SetToolMessage>>;
        getTool: Method<zInfer<typeof GetToolMessage>>;
        setToolSettings: Method<zInfer<typeof SetToolSettingsMessage>>;
        getToolSettings: Method<zInfer<typeof GetToolSettingsMessage>>;
    };
    listeners: {
        onToolChange: ListenerNoOptions<ToolType | null>;
        onToolSettingsChange: ListenerNoOptions<ToolSettingsChangeEvent>;
    };
};

declare const UiControlsMessage: z.ZodObject<{
    type: z.ZodLiteral<"updateUiControls">;
    params: z.ZodObject<{
        showLegend: z.ZodOptional<z.ZodBoolean>;
        cooperativeGestures: z.ZodOptional<z.ZodBoolean>;
        fullScreenButton: z.ZodOptional<z.ZodBoolean>;
        geolocation: z.ZodOptional<z.ZodBoolean>;
        zoomControls: z.ZodOptional<z.ZodBoolean>;
        scaleBar: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        showLegend?: boolean | undefined;
        cooperativeGestures?: boolean | undefined;
        fullScreenButton?: boolean | undefined;
        geolocation?: boolean | undefined;
        zoomControls?: boolean | undefined;
        scaleBar?: boolean | undefined;
    }, {
        showLegend?: boolean | undefined;
        cooperativeGestures?: boolean | undefined;
        fullScreenButton?: boolean | undefined;
        geolocation?: boolean | undefined;
        zoomControls?: boolean | undefined;
        scaleBar?: boolean | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        showLegend?: boolean | undefined;
        cooperativeGestures?: boolean | undefined;
        fullScreenButton?: boolean | undefined;
        geolocation?: boolean | undefined;
        zoomControls?: boolean | undefined;
        scaleBar?: boolean | undefined;
    };
    type: "updateUiControls";
}, {
    params: {
        showLegend?: boolean | undefined;
        cooperativeGestures?: boolean | undefined;
        fullScreenButton?: boolean | undefined;
        geolocation?: boolean | undefined;
        zoomControls?: boolean | undefined;
        scaleBar?: boolean | undefined;
    };
    type: "updateUiControls";
}>;
declare const OnMapInteractionsMessage: z.ZodObject<{
    type: z.ZodLiteral<"setOnMapInteractionsUi">;
    params: z.ZodObject<{
        featureSelectPanel: z.ZodOptional<z.ZodBoolean>;
        featureHoverPanel: z.ZodOptional<z.ZodBoolean>;
        elementSelectPanel: z.ZodOptional<z.ZodBoolean>;
        linkClickOpen: z.ZodOptional<z.ZodBoolean>;
        imageLightboxOpen: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        featureSelectPanel?: boolean | undefined;
        featureHoverPanel?: boolean | undefined;
        elementSelectPanel?: boolean | undefined;
        linkClickOpen?: boolean | undefined;
        imageLightboxOpen?: boolean | undefined;
    }, {
        featureSelectPanel?: boolean | undefined;
        featureHoverPanel?: boolean | undefined;
        elementSelectPanel?: boolean | undefined;
        linkClickOpen?: boolean | undefined;
        imageLightboxOpen?: boolean | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        featureSelectPanel?: boolean | undefined;
        featureHoverPanel?: boolean | undefined;
        elementSelectPanel?: boolean | undefined;
        linkClickOpen?: boolean | undefined;
        imageLightboxOpen?: boolean | undefined;
    };
    type: "setOnMapInteractionsUi";
}, {
    params: {
        featureSelectPanel?: boolean | undefined;
        featureHoverPanel?: boolean | undefined;
        elementSelectPanel?: boolean | undefined;
        linkClickOpen?: boolean | undefined;
        imageLightboxOpen?: boolean | undefined;
    };
    type: "setOnMapInteractionsUi";
}>;
declare const ShowLayerDataTableMessage: z.ZodObject<{
    type: z.ZodLiteral<"showLayerDataTable">;
    params: z.ZodOptional<z.ZodObject<{
        layerId: z.ZodString;
        sorting: z.ZodOptional<z.ZodObject<{
            attribute: z.ZodString;
            direction: z.ZodEnum<["asc", "desc"]>;
        }, "strip", z.ZodTypeAny, {
            attribute: string;
            direction: "asc" | "desc";
        }, {
            attribute: string;
            direction: "asc" | "desc";
        }>>;
    }, "strip", z.ZodTypeAny, {
        layerId: string;
        sorting?: {
            attribute: string;
            direction: "asc" | "desc";
        } | undefined;
    }, {
        layerId: string;
        sorting?: {
            attribute: string;
            direction: "asc" | "desc";
        } | undefined;
    }>>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "showLayerDataTable";
    params?: {
        layerId: string;
        sorting?: {
            attribute: string;
            direction: "asc" | "desc";
        } | undefined;
    } | undefined;
}, {
    type: "showLayerDataTable";
    params?: {
        layerId: string;
        sorting?: {
            attribute: string;
            direction: "asc" | "desc";
        } | undefined;
    } | undefined;
}>;
declare const HideLayerDataTableMessage: z.ZodObject<{
    type: z.ZodLiteral<"hideLayerDataTable">;
    params: z.ZodUndefined;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "hideLayerDataTable";
    params?: undefined;
}, {
    type: "hideLayerDataTable";
    params?: undefined;
}>;
type UiSchema = {
    methods: {
        updateUiControls: Method<zInfer<typeof UiControlsMessage>>;
        setOnMapInteractionsUi: Method<zInfer<typeof OnMapInteractionsMessage>>;
        showLayerDataTable: Method<zInfer<typeof ShowLayerDataTableMessage>>;
        hideLayerDataTable: Method<zInfer<typeof HideLayerDataTableMessage>>;
    };
    listeners: {};
};

declare const GetViewportMessage: z.ZodObject<{
    type: z.ZodLiteral<"getViewport">;
    params: z.ZodUndefined;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "getViewport";
    params?: undefined;
}, {
    type: "getViewport";
    params?: undefined;
}>;
declare const GotoViewportMessage: z.ZodObject<{
    type: z.ZodLiteral<"setViewport">;
    params: z.ZodObject<{
        center: z.ZodOptional<z.ZodObject<{
            latitude: z.ZodNumber;
            longitude: z.ZodNumber;
        }, "strip", z.ZodTypeAny, {
            latitude: number;
            longitude: number;
        }, {
            latitude: number;
            longitude: number;
        }>>;
        zoom: z.ZodOptional<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        center?: {
            latitude: number;
            longitude: number;
        } | undefined;
        zoom?: number | undefined;
    }, {
        center?: {
            latitude: number;
            longitude: number;
        } | undefined;
        zoom?: number | undefined;
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        center?: {
            latitude: number;
            longitude: number;
        } | undefined;
        zoom?: number | undefined;
    };
    type: "setViewport";
}, {
    params: {
        center?: {
            latitude: number;
            longitude: number;
        } | undefined;
        zoom?: number | undefined;
    };
    type: "setViewport";
}>;
declare const GetViewportConstraintsMessage: z.ZodObject<{
    type: z.ZodLiteral<"getViewportConstraints">;
    params: z.ZodUndefined;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    type: "getViewportConstraints";
    params?: undefined;
}, {
    type: "getViewportConstraints";
    params?: undefined;
}>;
declare const SetViewportConstraintsMessage: z.ZodObject<{
    type: z.ZodLiteral<"setViewportConstraints">;
    params: z.ZodNullable<z.ZodObject<{
        minZoom: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        maxZoom: z.ZodOptional<z.ZodNullable<z.ZodNumber>>;
        bounds: z.ZodOptional<z.ZodNullable<z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>>>;
    }, "strip", z.ZodTypeAny, {
        minZoom?: number | null | undefined;
        maxZoom?: number | null | undefined;
        bounds?: [number, number, number, number] | null | undefined;
    }, {
        minZoom?: number | null | undefined;
        maxZoom?: number | null | undefined;
        bounds?: [number, number, number, number] | null | undefined;
    }>>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        minZoom?: number | null | undefined;
        maxZoom?: number | null | undefined;
        bounds?: [number, number, number, number] | null | undefined;
    } | null;
    type: "setViewportConstraints";
}, {
    params: {
        minZoom?: number | null | undefined;
        maxZoom?: number | null | undefined;
        bounds?: [number, number, number, number] | null | undefined;
    } | null;
    type: "setViewportConstraints";
}>;
declare const ViewportFitBoundsMessage: z.ZodObject<{
    type: z.ZodLiteral<"fitViewportToBounds">;
    params: z.ZodObject<{
        bounds: z.ZodTuple<[z.ZodNumber, z.ZodNumber, z.ZodNumber, z.ZodNumber], null>;
    }, "strip", z.ZodTypeAny, {
        bounds: [number, number, number, number];
    }, {
        bounds: [number, number, number, number];
    }>;
}, z.UnknownKeysParam, z.ZodTypeAny, {
    params: {
        bounds: [number, number, number, number];
    };
    type: "fitViewportToBounds";
}, {
    params: {
        bounds: [number, number, number, number];
    };
    type: "fitViewportToBounds";
}>;
type ViewportSchema = {
    methods: {
        getViewport: Method<zInfer<typeof GetViewportMessage>>;
        setViewport: Method<zInfer<typeof GotoViewportMessage>>;
        getViewportConstraints: Method<zInfer<typeof GetViewportConstraintsMessage>>;
        setViewportConstraints: Method<zInfer<typeof SetViewportConstraintsMessage>>;
        fitViewportToBounds: Method<zInfer<typeof ViewportFitBoundsMessage>>;
    };
    listeners: {
        onViewportMove: ListenerNoOptions<ViewportState>;
        onViewportMoveEnd: ListenerNoOptions<ViewportState>;
        onMapIdle: ListenerNoOptions<void>;
    };
};

type AllModules = UiSchema | ViewportSchema | LayersSchema | ElementsSchema | SelectionSchema | InteractionsSchema | ToolsSchema | InteractionsSchema | MiscSchema;

type FeltHandlers = {
    methods: FeltMethodHandlers;
    listeners: FeltListenerHandlers;
};
type MethodSpec = UnionToIntersection<AllModules["methods"]>;
type ListenerSpec = UnionToIntersection<AllModules["listeners"]>;
type ExtractMethodParams<T extends Record<string, AnyFunction | {
    request: {
        params?: any;
    };
    response: any;
}>> = {
    [K in keyof T]: T[K] extends {
        request: {
            params?: any;
        };
        response: any;
    } ? {
        request: T[K]["request"]["params"];
        response: T[K]["response"];
    } : T[K];
};
type ExtractListenerParams<T extends Record<string, {
    options: any;
    eventParams: any;
} | {
    eventParams: any;
}>> = {
    [K in keyof T]: T[K] extends {
        options: any;
    } ? {
        options: T[K]["options"];
        eventParams: T[K]["eventParams"];
    } : {
        eventParams: T[K]["eventParams"];
    };
};
type AnyFunction = (...args: any[]) => any;
type MethodHandlers<T> = {
    [K in keyof T]: T[K] extends AnyFunction ? T[K] : (request: T[K] extends {
        request: any;
    } ? T[K]["request"] : never) => PromiseOrNot<T[K] extends {
        response: any;
    } ? T[K]["response"] : never>;
};
type FeltMethodHandlers = MethodHandlers<ExtractMethodParams<MethodSpec>>;
type ListenerHandlers<T> = {
    [K in keyof T]: (args: T[K] extends {
        options: any;
    } ? {
        handler: (event: T[K] extends {
            eventParams: any;
        } ? T[K]["eventParams"] : never) => void;
        options: T[K]["options"];
    } : {
        handler: (event: T[K] extends {
            eventParams: any;
        } ? T[K]["eventParams"] : never) => void;
    }) => VoidFunction;
};
type FeltListenerHandlers = ListenerHandlers<ExtractListenerParams<ListenerSpec>>;

/**
 * This function creates a message handler for the Felt SDK. Its job is to start listening
 * for messages from the Felt SDKl, validate and parses the messages before calling the
 * appropriate handler.
 *
 * @param feltWindow - The window to listen on, which is typically just `window`
 * @param handlers - The handlers to call for each type of message.
 * @param options - Optional callbacks for handling unknown and invalid messages.
 * @returns A function to stop the message handler.
 */
declare function createMessageHandler(feltWindow: Window, handlers: FeltHandlers, options?: {
    /**
     * Called when a message is received of an unknown type.
     *
     * @param message - The message that was received.
     */
    onUnknownMessage?: (message: unknown) => void;
    /**
     * Called when a message is received that matches a known
     * type, but fails to parse with the full schema.
     *
     * @param message
     */
    onInvalidMessage?: (message: unknown, error: ZodError) => void;
}): VoidFunction;

export { createMessageHandler };
